/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2001-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Offroy.
Contributor(s): ______________________________________.

====================================================================*/

/* TO DO verify|make compatibility with PocketPC */

#include "stdAfx.h"
#include <windows.h> 
#include "common.h" 

#define MAX_TASKS           10000 /* MAX task to show */

TASK_LIST	tlist[MAX_TASKS];

void Usage(void);
void printTask(TASK_LIST task,FILE *out);
void printProcessList(TASK_LIST *tlist,int numTask);

/***********************************
 * ps.exe                          *
 * Usage : ps.exe [--help|/?|-?]   *
 *                                 *
 * list system process             *
 ***********************************/

void main(int argc, char **argv){
	DWORD		numTasks;
	LPGetTaskList     GetTaskList;
	OSVERSIONINFO     verInfo = {0};
	
	/* parse argument */
	if (	(argc > 1) && 
		(( (argv[1][0] == '-' || argv[1][0] == '/') && (argv[1][1] == '?')) 
		|| (strcmp(argv[1],"--help") == 0) ) 
		) { 
        Usage(); 
    }
	
	/* Determine what system we're on and do the right thing */
    verInfo.dwOSVersionInfoSize = sizeof (verInfo); 
    GetVersionEx(&verInfo); 
	
    switch (verInfo.dwPlatformId) { 
		case VER_PLATFORM_WIN32_NT: 
			GetTaskList     = GetTaskListNT; 
			/*EnableDebugPriv = EnableDebugPrivNT; */
			break; 
		
		case VER_PLATFORM_WIN32_WINDOWS: 
			GetTaskList = GetTaskList95; 
			/*EnableDebugPriv = EnableDebugPriv95; */
			break; 
			
		default: 
			printf ("ps requires Windows NT or Windows 95/98/XP/2000\n"); 
    }
	
	
	numTasks = GetTaskList( tlist, MAX_TASKS );
	printProcessList(tlist,numTasks);
}

/********************
 * internal methods *
 ********************/
void Usage(){
    fprintf( stderr, "usage: ps [--help|/?|-?]\n" ); 
    ExitProcess(0); 

}

void printTask(TASK_LIST task,FILE *out){
	fprintf(out,"%5d %-16s",task.dwProcessId,task.ProcessName);
	fprintf(out,"%s",task.WindowTitle);
	fprintf(out,"\n");
}

void printProcessList(TASK_LIST *tlist,int numTask){
	int i;
	for(i = 0 ; i < numTask ; i++){
		printTask(tlist[i],stdout);
	}
}
