/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Sylvain Leblanc.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.ccm.hello;

/**
 * This is the implementation of the OMG IDL3 hello::Server component type.
 *
 * This class inherits from the local CCM_Server interface
 * generated by the OpenCCM's IDL3 to IDL2 mapping generator.
 *
 * The provided for_clients facet is directly implemented by the
 * component class by implementing the hello::Hello interface.
 */

public class ServerImpl
     extends org.omg.CORBA.LocalObject
  implements CCM_Server,
             CCM_HelloWorld, 
             org.omg.Components.SessionComponent
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** To refer to the component context. */
    private CCM_Server_Context the_context_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    ServerImpl()
    {
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL Components::EnterpriseComponent
    //
    // ==================================================================

    /**
     * Complete the component configuration.
     *
     * @exception org.omg.Components.InvalidConfiguration
     *            Thrown if the configuration is invalid.
     */
    public void
    configuration_complete ()
    throws org.omg.Components.InvalidConfiguration
    {
        // Nothing to test.
    }

    // ==================================================================
    //
    // Methods for OMG IDL Components::SessionComponent
    //
    // ==================================================================

    /**
     * Set the component context.
     *
     * @param context The component context.
     *
     * @throw org.omg.Components.CCMException For any problems.
     */
    public void
    set_session_context(org.omg.Components.SessionContext context)
    throws org.omg.Components.CCMException
    {
        the_context_ = (CCM_Server_Context)context;
    }

    //
    //  IDL:omg.org/Components/SessionComponent/ccm_activate:1.0
    //
    /**
     *
     * Called by the container when the component will be activated.
     *
     *  @throws org.omg.Components.CCMException
     *          Thrown if a system level error occured.
     */
    public void
    ccm_activate()
    throws org.omg.Components.CCMException
    {
	// Not implemented
    }

    //
    //  IDL:omg.org/Components/SessionComponent/ccm_passivate:1.0
    //
    /**
     *
     * Called by the container when the component will be passivated.
     *
     *  @throws org.omg.Components.CCMException
     *          Thrown if a system level error occured.
     */
    public void 
    ccm_passivate()
    throws org.omg.Components.CCMException
    {
	// Not implemented
    }

    //
    //  IDL:omg.org/Components/SessionComponent/ccm_remove:1.0
    //
    /**
     *
     * Called by the container when the component will be removed.
     *
     *  @throws org.omg.Components.CCMException
     *          Thrown if a system level error occured.
     */
    public void 
    ccm_remove()
    throws org.omg.Components.CCMException
    {
	// nothing to do.
    }

    // ==================================================================
    //
    // Methods for OMG IDL hello::CCM_HelloWorld
    //
    // ==================================================================

    /**
     * The say_hello operation of the hello::HelloWorld interface.
     */
    public void
    say_hello()
    {
        // Puts the hello string in error output
	// (standard output is redirected to a logging file).
        System.err.println("hello world !!") ;
    }

    // ==================================================================
    //
    // Methods for OMG IDL hello::CCM_Server
    //
    // ==================================================================

    /**
     * Provide the executor for the for_clients facet.
     *
     * @return An executor implemening CCM_HelloWorld. 
     */
    public CCM_HelloWorld
    get_for_clients()
    {
        return this;
    }
}
